import React, { FC } from 'react';
import { UserManager, User } from 'oidc-client';
export interface Location {
    search: string;
    hash: string;
}
export interface AuthProviderProps {
    /**
     * See [UserManager](https://github.com/IdentityModel/oidc-client-js/wiki#usermanager) for more details.
     */
    userManager?: UserManager;
    /**
     * The URL of the OIDC/OAuth2 provider.
     */
    authority?: string;
    /**
     * Your client application's identifier as registered with the OIDC/OAuth2 provider.
     */
    clientId?: string;
    /**
     * The redirect URI of your client application to receive a response from the OIDC/OAuth2 provider.
     */
    redirectUri?: string;
    /**
     * Tells the authorization server which grant to execute
     *
     * Read more: https://tools.ietf.org/html/rfc6749#section-3.1.1
     */
    responseType?: string;
    /**
     * A space-delimited list of permissions that the application requires.
     */
    scope?: string;
    /**
     * Defaults to `windows.location`.
     */
    location?: Location;
    /**
     * defaults to true
     */
    autoSignIn?: boolean;
    /**
     * On sign out hook. Can be a async function.
     * @param userData User
     */
    onSignIn?: (userData: User | null) => Promise<void>;
    /**
     * On sign out hook. Can be a async function.
     */
    onSignOut?: () => Promise<void>;
}
export interface AuthContextProps {
    signIn: () => void;
    signOut: () => void;
    /**
     * See [User](https://github.com/IdentityModel/oidc-client-js/wiki#user) for more details.
     */
    userData?: User | null;
}
export declare const AuthContext: React.Context<AuthContextProps>;
/**
 *
 * @param props AuthProviderProps
 */
export declare const AuthProvider: FC<AuthProviderProps>;
