/* eslint @typescript-eslint/no-explicit-any: 0 */
/* eslint @typescript-eslint/explicit-function-return-type: 0 */
import React from 'react';
import { UserManager } from 'oidc-client';
import { AuthProvider, AuthContext } from '../AuthContext';
import { render, act, waitFor } from '@testing-library/react';
jest.mock('oidc-client');
describe('AuthContext', () => {
    it('should check for user and redirect', async () => {
        await act(async () => {
            const u = {
                getUser: jest.fn(),
                signinRedirect: jest.fn(),
            };
            render(React.createElement(AuthProvider, { userManager: u }));
            await waitFor(() => expect(u.getUser).toHaveBeenCalled());
            await waitFor(() => expect(u.signinRedirect).toHaveBeenCalled());
        });
    });
    it('should redirect when asked', async () => {
        await act(async () => {
            const u = {
                getUser: jest.fn(),
                signinRedirect: jest.fn(),
            };
            render(React.createElement(AuthProvider, { userManager: u, autoSignIn: false },
                React.createElement(AuthContext.Consumer, null, (value) => {
                    value.signIn();
                    return React.createElement("p", null, "Bjerk");
                })));
            await waitFor(() => expect(u.getUser).toHaveBeenCalled());
            await waitFor(() => expect(u.signinRedirect).toHaveBeenCalled());
        });
    });
    it('should not redirect when asked', async () => {
        await act(async () => {
            const u = {
                getUser: jest.fn(),
            };
            render(React.createElement(AuthProvider, { userManager: u, autoSignIn: false }));
            await waitFor(() => expect(u.getUser).toHaveBeenCalled());
        });
    });
    it('should generate a UserManager', async () => {
        render(React.createElement(AuthProvider, { authority: "http://127.0.0.1", clientId: "client-id-test", redirectUri: "http://127.0.0.1" }));
        await waitFor(() => expect(UserManager).toHaveBeenCalled());
    });
    it('should get userData', async () => {
        await act(async () => {
            const userManager = {
                getUser: async () => ({
                    access_token: 'token',
                }),
                signinRedirectCallback: jest.fn(),
            };
            const { getByText } = render(React.createElement(AuthProvider, { userManager: userManager },
                React.createElement(AuthContext.Consumer, null, (value) => value.userData && (React.createElement("span", null,
                    "Received: ",
                    value.userData.access_token)))));
            await waitFor(() => expect(getByText(/^Received:/).textContent).toBe('Received: token'));
        });
    });
    it('should login the user', async () => {
        const userManager = {
            getUser: jest.fn(),
            signinRedirectCallback: jest.fn(),
        };
        const location = {
            search: '?code=test-code',
            hash: '',
        };
        const onSignIn = jest.fn();
        render(React.createElement(AuthProvider, { onSignIn: onSignIn, userManager: userManager, location: location }));
        await waitFor(() => expect(onSignIn).toHaveBeenCalled());
        await waitFor(() => expect(userManager.signinRedirectCallback).toHaveBeenCalled());
    });
    it('should logout the user', async () => {
        const userManager = {
            getUser: async () => ({
                access_token: 'token',
            }),
            removeUser: jest.fn(),
        };
        const onSignOut = jest.fn();
        render(React.createElement(AuthProvider, { onSignOut: onSignOut, userManager: userManager, location: location },
            React.createElement(AuthContext.Consumer, null, (value) => {
                value.signOut();
                return React.createElement("p", null, "Bjerk");
            })));
        await waitFor(() => expect(onSignOut).toHaveBeenCalled());
        await waitFor(() => expect(userManager.removeUser).toHaveBeenCalled());
    });
});
